@@ -67,6 +67,7 @@ def add_population_column(
     date_column: str | None = None,
     target_column: str = "population",
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add population column to a dataframe
 
@@ -82,6 +83,7 @@ def add_population_column(
             the world bank is used.
         target_column: the column where the population data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the population data.
@@ -98,6 +100,7 @@ def add_population_column(
     pop_df = get_population_df(
         most_recent_only=True if date_column is None else False,
         update_population_data=update_data,
+        data_path=data_path,
     ).rename(columns={"iso_code": "id_"})
 
     df[target_column] = df_.merge(pop_df, on=on_, how="left").population
@@ -112,6 +115,7 @@ def add_poverty_ratio_column(
     date_column: str | None = None,
     target_column: str = "poverty_ratio",
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add poverty headcount column to a dataframe
 
@@ -126,6 +130,7 @@ def add_poverty_ratio_column(
             column as well. If the data isn't specified, the most recent data is used.
         target_column: the column where the population data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the poverty data.
@@ -142,6 +147,7 @@ def add_poverty_ratio_column(
     pov_df = get_poverty_ratio_df(
         most_recent_only=True if date_column is None else False,
         update_poverty_data=update_data,
+        data_path=data_path,
     ).rename(columns={"iso_code": "id_"})
 
     df[target_column] = df_.merge(pov_df, on=on_, how="left").poverty_headcount_ratio
@@ -156,6 +162,7 @@ def add_population_density_column(
     date_column: str | None = None,
     target_column: str = "population_density",
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add population density column to a dataframe
 
@@ -187,6 +194,7 @@ def add_population_density_column(
     pov_df = get_population_density_df(
         most_recent_only=True if date_column is None else False,
         update_population_data=update_data,
+        data_path=data_path,
     ).rename(columns={"iso_code": "id_"})
 
     df[target_column] = df_.merge(pov_df, on=on_, how="left").population_density
@@ -203,6 +211,7 @@ def add_gdp_column(
     usd: bool = True,
     include_estimates: bool = False,
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add GDP column to a dataframe
 
@@ -220,6 +229,7 @@ def add_gdp_column(
         usd: Whether to add the data as US dollars or Local Currency Units.
         target_column: the column where the gdp data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the gdp data from
@@ -239,6 +249,7 @@ def add_gdp_column(
         most_recent_only=True if date_column is None else False,
         include_estimates=include_estimates,
         update_gdp_data=update_data,
+        data_path=data_path,
     ).rename(columns={"iso_code": "id_", "value": "gdp"})
 
     # Create a deep copy of the dataframe to avoid overwriting the original data
@@ -257,6 +268,7 @@ def add_gov_expenditure_column(
     usd: bool = True,
     include_estimates: bool = False,
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add Government Expenditure column to a dataframe
 
@@ -274,6 +286,7 @@ def add_gov_expenditure_column(
         usd: Whether to add the data as US dollars or Local Currency Units.
         target_column: the column where the expenditure data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the expenditure data from
@@ -293,6 +306,7 @@ def add_gov_expenditure_column(
         most_recent_only=True if date_column is None else False,
         include_estimates=include_estimates,
         update_data=update_data,
+        data_path=data_path,
     ).rename(columns={"iso_code": "id_", "value": "gov_exp"})
 
     # Create a deep copy of the dataframe to avoid overwriting the original data
@@ -313,6 +327,7 @@ def add_gdp_share_column(
     usd: bool = False,
     include_estimates: bool = False,
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add value as share of GDP column to a dataframe
 
@@ -332,6 +347,7 @@ def add_gdp_share_column(
         usd: Whether to add the data as US dollars or Local Currency Units.
         target_column: the column where the gdp data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the data as a share
@@ -362,6 +378,7 @@ def add_population_share_column(
     target_column: str = "population_share",
     decimals: int = 2,
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add population share column to a dataframe
 
@@ -379,6 +396,7 @@ def add_population_share_column(
         target_column: the column where the population data will be stored.
         decimals: the number of decimals to use in the returned column.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing value as share of
@@ -411,6 +429,7 @@ def add_gov_exp_share_column(
     usd: bool = False,
     include_estimates: bool = False,
     update_data: bool = False,
+    data_path: str | None = None,
 ) -> pd.DataFrame:
     """Add value as share of Government Expenditure column to a dataframe
 
@@ -429,6 +448,7 @@ def add_gov_exp_share_column(
         usd: Whether to add the data as US dollars or Local Currency Units.
         target_column: the column where the expenditure data will be stored.
         update_data: whether to update the underlying data or not.
+        data_path: the path to the data folder. If None, the default data folder is used.
 
     Returns:
         DataFrame: the original DataFrame with a new column containing the data as a share
