@@ -12,8 +12,8 @@ import warnings
 
 from weo import all_releases, download, WEO
 
-from bblocks.config import PATHS
 from bblocks.cleaning_tools.clean import clean_numeric_series
+
 from bblocks.import_tools.common import ImportData
 
 
@@ -174,13 +174,13 @@ class SDR(ImportData):
         # make sure indicators are valid
         indicator_list = _check_sdr_indicators(indicator)
 
-        if not os.path.exists(f"{PATHS.imported_data}/{self.file_name}") or (
+        if not os.path.exists(f"{self.data_path}/{self.file_name}") or (
             self.update_data and self.data is None
         ):
             self.update(reload_data=False)
 
         if self.data is None:
-            self.data = pd.read_csv(f"{PATHS.imported_data}/{self.file_name}")
+            self.data = pd.read_csv(f"{self.data_path}/{self.file_name}")
 
         for i in indicator_list:
             self.indicators[i] = self.data[self.data["indicator"] == i].reset_index(
@@ -226,7 +226,7 @@ class SDR(ImportData):
 
         (
             df.assign(date=latest_date).to_csv(
-                f"{PATHS.imported_data}/{self.file_name}", index=False
+                f"{self.data_path}/{self.file_name}", index=False
             )
         )
 
@@ -305,26 +305,36 @@ def _check_weo_parameters(
     return latest_y, latest_r
 
 
-def _update_weo(latest_y: int = None, latest_r: int = None) -> None:
+def _update_weo(
+    latest_y: int = None,
+    latest_r: int = None,
+    data_path: str = None,
+) -> None:
     """Update data from the World Economic Outlook, using WEO package"""
 
+    if data_path is None:
+        raise ValueError("Please specify a data path")
+
+    if data_path[-1] == "/":
+        data_path = data_path[:-1]
+
     latest_y, latest_r = _check_weo_parameters(latest_y, latest_r)
 
     # Download the file from the IMF website and store in directory
     download(
         latest_y,
         latest_r,
-        directory=PATHS.imported_data,
+        directory=data_path,
         filename=f"weo{latest_y}_{latest_r}.csv",
     )
 
     # Validate the file
-    if os.path.getsize(f"{PATHS.imported_data}/weo{latest_y}_{latest_r}.csv") < 1000:
+    if os.path.getsize(f"{data_path}/weo{latest_y}_{latest_r}.csv") < 1000:
         print(
             f"Downloading release {latest_r} of "
             f"{latest_y} failed. Trying previous release"
         )
-        os.remove(f"{PATHS.imported_data}/weo{latest_y}_{latest_r}.csv")
+        os.remove(f"{data_path}/weo{latest_y}_{latest_r}.csv")
 
         try:
             _update_weo(latest_y, latest_r - 1)
@@ -370,21 +380,21 @@ class WorldEconomicOutlook(ImportData):
 
         # If data doesn't exist or update is required, update the data
         if (
-            not os.path.exists(f"{PATHS.imported_data}/weo{latest_y}_{latest_r}.csv")
+            not os.path.exists(f"{self.data_path}/weo{latest_y}_{latest_r}.csv")
             or self.update_data
         ):
             _update_weo(latest_y, latest_r)
 
         # Load the data from disk. If it doesn't exist, try the previous one
         try:
-            df = WEO(PATHS.imported_data + rf"/weo{latest_y}_{latest_r}.csv").df
+            df = WEO(f"{self.data_path}/weo{latest_y}_{latest_r}.csv").df
             self.version = {"year": latest_y, "release": latest_r}
         except FileNotFoundError:
             try:
-                df = WEO(PATHS.imported_data + rf"/weo{latest_y}_{latest_r-1}.csv").df
+                df = WEO(f"{self.data_path}/weo{latest_y}_{latest_r-1}.csv").df
                 self.version = {"year": latest_y, "release": latest_r - 1}
             except FileNotFoundError:
-                df = WEO(PATHS.imported_data + rf"/weo{latest_y-1}_{latest_r}.csv").df
+                df = WEO(f"{self.data_path}/weo{latest_y-1}_{latest_r}.csv").df
                 self.version = {"year": latest_y - 1, "release": latest_r}
 
         # Load data into data object
